@@ -3,12 +3,14 @@ class BaseDrawError(Exception):
     draw github poster wrong
     """
 
-    pass
-
 
 class CircularDrawError(BaseDrawError):
     """
     draw circular poster wrong
     """
 
-    pass
+
+class DepNotInstalledError(Exception):
+    """
+    optional dependency not installed
+    """
