@@ -13,7 +13,7 @@ from github_poster.loader.jike_loader import JikeLoader
 from github_poster.loader.json_loader import JsonLoader
 from github_poster.loader.kindle_loader import KindleLoader
 from github_poster.loader.leetcode_loader import LeetcodeLoader
-from github_poster.loader.multiple_loader import MutipleLoader
+from github_poster.loader.multiple_loader import MultipleLoader
 from github_poster.loader.notion_loader import NotionLoader
 from github_poster.loader.nrc_loader import NRCLoader
 from github_poster.loader.ns_loader import NSLoader
@@ -43,7 +43,7 @@ LOADER_DICT = {
     "kindle": KindleLoader,
     "wakatime": WakaTimeLoader,
     "dota2": Dota2Loader,
-    "multiple": MutipleLoader,
+    "multiple": MultipleLoader,
     "nike": NRCLoader,
     "notion": NotionLoader,
     "garmin": GarminLoader,
@@ -71,7 +71,7 @@ __all__ = (
     "TwitterLoader",
     "WakaTimeLoader",
     "YouTubeLoader",
-    "MutipleLoader",
+    "MultipleLoader",
     "NotionLoader",
     "NRCLoader",
     "LOADER_DICT",
